@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,7 +65,9 @@ typedef enum
 	M_HAVE_MULTI_ACCOUNT  = 1 << 24,
 	M_FOLDER_SELECTED     = 1 << 25,
 	M_SESSION_PASSWORDS   = 1 << 26,
-	M_DELETED_EXISTS      = 1 << 27
+	M_DELETED_EXISTS      = 1 << 27,
+	M_NOT_TRASH	      = 1 << 28,
+	M_HIDE_READ_THREADS   = 1 << 29
 } SensitiveCond;
 
 typedef enum
